..
   Copyright (C) 2014 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


Moments
=======

.. currentmodule:: bayespy.inference.vmp.nodes

.. autosummary::
   :toctree: generated/

   node.Moments
   gaussian.GaussianMoments
   gaussian_markov_chain.GaussianMarkovChainMoments
   gaussian.GaussianGammaMoments
   gaussian.GaussianWishartMoments
   gamma.GammaMoments
   wishart.WishartMoments
   beta.BetaMoments
   dirichlet.DirichletMoments
   bernoulli.BernoulliMoments
   binomial.BinomialMoments
   categorical.CategoricalMoments
   categorical_markov_chain.CategoricalMarkovChainMoments
   multinomial.MultinomialMoments
   poisson.PoissonMoments
